{
  config,
  lib,
  pkgs,
  ...
}:

{
  imports = [ ./hardware-configuration.nix ];

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  time.timeZone = "Europe/Paris";

  systemd.network = {
    enable = true;
    networks."10-enp1s0" = {
      name = "enp1s0";
      address = [
        "192.168.122.3/24"
        "fe80::3/64"
      ];
      routes = [
        { routeConfig.Gateway = "192.168.122.1"; }
        { routeConfig.Gateway = "fe80::1"; }
      ];
    };
  };

  networking = {
    useDHCP = false;
    nameservers = [
      "192.168.122.1"
      "fe80::1%enp1s0"
    ];
  };

  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "fr";
  };

  services.dbus.packages = with pkgs; [ dconf ];

  nixpkgs.config.allowUnfree = true;

  environment.systemPackages = with pkgs; [
    wget
    nix-search-cli
    git
    btop
    ranger
    screen
    gnumake
  ];

  services.gitlab-runner = {
    enable = true;
    services.parkas = {
      executor = "shell";
      registrationConfigFile = "/root/parkas-runner-secrets.toml";
      tagList = [
        "test"
        "linux"
        "nix"
      ];
    };
  };

  programs.gnupg.agent = {
    enable = true;
    enableSSHSupport = true;
  };

  services.openssh.enable = true;

  networking.firewall.enable = false;

  system.stateVersion = "23.11";
}
